CalendarController class
Core controller that manages the current date and view type for the calendar.
Provides navigation methods to move between days, weeks, months, and years, and notifies listeners on every change.
- Inheritance
-
- Object
- ChangeNotifier
- CalendarController
Constructors
- CalendarController({DateTime? initialDate, CalendarViewType viewType = CalendarViewType.month})
Properties
- currentDate → DateTime
-
no setter
- currentMonth → int
-
no setter
- currentYear → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewType → CalendarViewType
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
goToToday(
) → void - Navigates to today's date.
-
nextDay(
) → void - Advances to the next day.
-
nextMonth(
) → void - Advances to the next month.
-
nextWeek(
) → void - Advances to the next week.
-
nextYear(
) → void - Advances to the next year.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
previousDay(
) → void - Goes back to the previous day.
-
previousMonth(
) → void - Goes back to the previous month.
-
previousWeek(
) → void - Goes back to the previous week.
-
previousYear(
) → void - Goes back to the previous year.
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setDate(
DateTime date) → void -
Sets the current date to
dateand notifies listeners. -
setViewType(
CalendarViewType type) → void - Switches the calendar view type (month, week, day, etc.).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited