setDate method
Sets the current date to date and notifies listeners.
Implementation
void setDate(DateTime date) {
_currentDate = date;
notifyListeners();
}
Sets the current date to date and notifies listeners.
void setDate(DateTime date) {
_currentDate = date;
notifyListeners();
}