DragController class

拖拽控制器

Inheritance

Constructors

DragController()

Properties

draggingEventId String?
no setter
dragOffset Offset
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isDragging bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
calculateNewTime(DateTime originalTime, double hourHeight, double dayWidth) DateTime
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
endDrag() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
startDrag(String eventId) → void
toString() String
A string representation of this object.
inherited
updateDrag(Offset delta) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited