setMode method
Changes the selection mode and clears any existing selection.
Implementation
void setMode(SelectionMode mode) {
_mode = mode;
clearSelection();
}
Changes the selection mode and clears any existing selection.
void setMode(SelectionMode mode) {
_mode = mode;
clearSelection();
}