CalendarConfig class
Configuration for the calendar component.
Controls the calendar system, view type, display options (lunar dates, holidays, solar terms), interaction modes (selection, drag, resize), and date constraints.
Constructors
-
CalendarConfig({CalendarSystem system = CalendarSystem.gregorian, int firstDayOfWeek = 1, Locale locale = const Locale('zh', 'CN'), CalendarViewType viewType = CalendarViewType.month, bool showWeekNumber = false, bool showLunar = true, bool showHolidays = true, bool showSolarTerms = true, int dayStartHour = 0, int dayEndHour = 24, int timeSlotMinutes = 30, SelectionMode selectionMode = SelectionMode.single, bool enableDrag = false, bool enableResize = false, bool enableCreate = true, DateTime? minDate, DateTime? maxDate, Set<
DateTime> ? disabledDates}) -
const
Properties
- dayEndHour → int
-
final
- dayStartHour → int
-
final
-
disabledDates
→ Set<
DateTime> ? -
final
- enableCreate → bool
-
final
- enableDrag → bool
-
final
- enableResize → bool
-
final
- firstDayOfWeek → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale → Locale
-
final
- maxDate → DateTime?
-
final
- minDate → DateTime?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionMode → SelectionMode
-
final
- showHolidays → bool
-
final
- showLunar → bool
-
final
- showSolarTerms → bool
-
final
- showWeekNumber → bool
-
final
- system → CalendarSystem
-
final
- timeSlotMinutes → int
-
final
- viewType → CalendarViewType
-
final
Methods
-
copyWith(
{CalendarSystem? system, int? firstDayOfWeek, Locale? locale, CalendarViewType? viewType, bool? showWeekNumber, bool? showLunar, bool? showHolidays, bool? showSolarTerms, int? dayStartHour, int? dayEndHour, int? timeSlotMinutes, SelectionMode? selectionMode, bool? enableDrag, bool? enableResize, bool? enableCreate, DateTime? minDate, DateTime? maxDate, Set< DateTime> ? disabledDates}) → CalendarConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited