IslamicDate class
Represents a date in the Islamic (Hijri) calendar.
This is a placeholder implementation for future expansion.
Constructors
- IslamicDate({required int year, required int month, required int day})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited