EventRepeat class
Defines a recurrence rule for a calendar event.
Supports daily, weekly, monthly, and yearly repetition with an optional end date or maximum number of occurrences.
Constructors
-
EventRepeat({required RepeatType type, int interval = 1, List<
int> ? weekdays, int? dayOfMonth, DateTime? endDate, int? occurrences}) -
const
Properties
- dayOfMonth → int?
-
final
- endDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval → int
-
final
- occurrences → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → RepeatType
-
final
-
weekdays
→ List<
int> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited