DateRange class

An inclusive date range defined by a start and end date.

Constructors

DateRange(DateTime start, DateTime end)
const

Properties

dayCount int
The total number of days in this range (inclusive).
no setter
days List<DateTime>
Returns a list of all dates in this range, one per day.
no setter
end DateTime
The last date in the range (inclusive).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
The first date in the range.
final

Methods

contains(DateTime date) bool
Returns true if date falls within this range (inclusive of both ends).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited