dayCount property
int
get
dayCount
The total number of days in this range (inclusive).
Implementation
int get dayCount => end.difference(start).inDays + 1;
The total number of days in this range (inclusive).
int get dayCount => end.difference(start).inDays + 1;