TimeSlot class

A time slot with a start and end time, typically used for booking or scheduling.

Constructors

TimeSlot({required DateTime start, required DateTime end, bool isAvailable = true})
const

Properties

duration Duration
The duration of this time slot.
no setter
end DateTime
The end time of the slot.
final
hashCode int
The hash code for this object.
no setterinherited
isAvailable bool
Whether this time slot is available for booking.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
The start time of the slot.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overlaps(TimeSlot other) bool
Returns true if this time slot overlaps with other.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited