ActivityHeatmap class

Activity heatmap variant with customizable colors and date range. Unlike the GitHub heatmap which is year-based, this supports arbitrary date ranges and multiple color schemes.

Inheritance

Constructors

ActivityHeatmap({Key? key, required DateTime startDate, required DateTime endDate, required Map<DateTime, int> data, List<Color>? colorStops, String? title, double cellSize = 14, double cellSpacing = 2, bool showMonthLabels = true, bool showWeekdayLabels = true, ValueChanged<DateTime>? onDayTap})
const

Properties

cellSize double
final
cellSpacing double
final
colorStops List<Color>?
final
data Map<DateTime, int>
final
endDate DateTime
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDayTap ValueChanged<DateTime>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showMonthLabels bool
final
showWeekdayLabels bool
final
startDate DateTime
final
title String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited