GitHubHeatmap class

GitHub contribution graph style heatmap calendar. Takes a Map<DateTime, int> of data and displays colored squares with week/month labels and a legend.

Inheritance

Constructors

GitHubHeatmap({Key? key, required int year, required Map<DateTime, int> data, Color baseColor = const Color(0xFF4CAF50), int levels = 5, double cellSize = 12, double cellSpacing = 2, ValueChanged<DateTime>? onDayTap})
const

Properties

baseColor Color
final
cellSize double
final
cellSpacing double
final
data Map<DateTime, int>
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
levels int
final
onDayTap ValueChanged<DateTime>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
year int
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited