build method

  1. @override
Widget build(
  1. BuildContext context
)
override

Describes the part of the user interface represented by this widget.

The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.

The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.

Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.

The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.

The implementation of this method must only depend on:

If a widget's build method is to depend on anything else, use a StatefulWidget instead.

See also:

  • StatelessWidget, which contains the discussion on performance considerations.

Implementation

@override
Widget build(BuildContext context) {
  final theme = Theme.of(context);
  final l = AppLocalizations.of(context);
  final firstDay = DateTime(year, 1, 1);
  final lastDay = DateTime(year, 12, 31);
  final totalDays = lastDay.difference(firstDay).inDays + 1;

  // Build weeks (columns). Each column is a week starting on Monday.
  final firstMonday = firstDay.subtract(
    Duration(days: (firstDay.weekday - 1) % 7),
  );

  // Calculate total weeks
  final totalWeeks =
      ((lastDay.difference(firstMonday).inDays) / 7).ceil() + 1;

  return Column(
    crossAxisAlignment: CrossAxisAlignment.start,
    mainAxisSize: MainAxisSize.min,
    children: [
      // Title
      Padding(
        padding: const EdgeInsets.only(bottom: 8),
        child: Row(
          children: [
            Text(
              l.dayData(totalDays),
              style: theme.textTheme.bodySmall?.copyWith(color: Colors.grey),
            ),
            const Spacer(),
            Text(
              '$year',
              style: theme.textTheme.titleSmall?.copyWith(
                fontWeight: FontWeight.w600,
              ),
            ),
          ],
        ),
      ),
      // Month labels
      _buildMonthLabels(context, theme, firstMonday, totalWeeks),
      const SizedBox(height: 4),
      // Grid with weekday labels
      Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          // Weekday labels (Mon, Wed, Fri)
          _buildWeekdayLabels(context, theme),
          const SizedBox(width: 4),
          // Heatmap grid
          Expanded(child: _buildGrid(firstMonday, totalWeeks)),
        ],
      ),
      const SizedBox(height: 8),
      // Legend
      _buildLegend(context, theme),
    ],
  );
}