CalendarThemeData class
Theme data that defines the visual appearance of calendar components.
Includes colors for today, selected dates, weekends, holidays, and disabled states, as well as text styles for day numbers, lunar labels, headers, and weekday labels.
Constructors
- CalendarThemeData({Color primaryColor = const Color(0xFF2196F3), Color todayColor = const Color(0xFF2196F3), Color selectedColor = const Color(0xFF1976D2), Color rangeColor = const Color(0xFFBBDEFB), Color weekendColor = const Color(0xFFEF5350), Color disabledColor = const Color(0xFFBDBDBD), Color holidayColor = const Color(0xFFE91E63), Color backgroundColor = Colors.white, Color surfaceColor = const Color(0xFFF5F5F5), Color headerColor = const Color(0xFF212121), TextStyle dayTextStyle = const TextStyle(fontSize: 16), TextStyle lunarTextStyle = const TextStyle(fontSize: 10, color: Color(0xFF757575)), TextStyle headerTextStyle = const TextStyle(fontSize: 18, fontWeight: FontWeight.bold, color: Color(0xFF212121)), TextStyle weekdayTextStyle = const TextStyle(fontSize: 13, fontWeight: FontWeight.w500, color: Color(0xFF757575)), double cellRadius = 8, double cellPadding = 4})
-
const
Properties
- backgroundColor → Color
-
final
- cellPadding → double
-
final
- cellRadius → double
-
final
- dayTextStyle → TextStyle
-
final
- disabledColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerColor → Color
-
final
- headerTextStyle → TextStyle
-
final
- holidayColor → Color
-
final
- lunarTextStyle → TextStyle
-
final
- primaryColor → Color
-
final
- rangeColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedColor → Color
-
final
- surfaceColor → Color
-
final
- todayColor → Color
-
final
- weekdayTextStyle → TextStyle
-
final
- weekendColor → Color
-
final
Methods
-
copyWith(
{Color? primaryColor, Color? todayColor, Color? selectedColor, Color? backgroundColor}) → CalendarThemeData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited