DayView class

A full-day view with a vertically scrollable 24-hour (configurable) time grid.

Events are positioned on the timeline according to their start/end times. A red current-time indicator is shown when date is today.

Inheritance

Constructors

DayView({Key? key, required DateTime date, CalendarConfig config = const CalendarConfig(), List<CalendarEvent> events = const [], ValueChanged<DateTime>? onTimeTap, ValueChanged<CalendarEvent>? onEventTap})
const

Properties

config CalendarConfig
Calendar configuration (hour range, etc.).
final
date DateTime
The date to display.
final
events List<CalendarEvent>
Events occurring on date.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onEventTap ValueChanged<CalendarEvent>?
Called when the user taps on an event card.
final
onTimeTap ValueChanged<DateTime>?
Called when the user taps on an empty time slot.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DayView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited