timeColumnWidth property
Width reserved for the time-label column; the indicator starts from this offset so it does not overlap the labels.
Implementation
final double timeColumnWidth;
Width reserved for the time-label column; the indicator starts from this offset so it does not overlap the labels.
final double timeColumnWidth;