top property
Vertical offset from the top of the parent Stack (pre-calculated by the parent based on the current time).
Implementation
final double top;
Vertical offset from the top of the parent Stack (pre-calculated by the parent based on the current time).
final double top;