InfiniteScrollDateList class

无限滚动日期列表 上下滚动可无限浏览日期,适合作为日期选择器

Inheritance

Constructors

InfiniteScrollDateList({Key? key, required DateTime initialDate, DateTime? selectedDate, ValueChanged<DateTime>? onDateSelected, bool showLunar = true, bool showEventIndicator = false, double itemHeight = 64, Set<DateTime>? disabledDates, DateTime? minDate, DateTime? maxDate})
const

Properties

disabledDates Set<DateTime>?
禁用日期集合
final
hashCode int
The hash code for this object.
no setterinherited
initialDate DateTime
初始聚焦日期
final
itemHeight double
每项高度
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxDate DateTime?
最晚日期
final
minDate DateTime?
最早日期
final
onDateSelected ValueChanged<DateTime>?
日期选中回调
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDate DateTime?
选中的日期
final
showEventIndicator bool
是否显示事件指示
final
showLunar bool
是否显示农历信息
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<InfiniteScrollDateList>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited