ScrollDatePicker class

滚动式日期选择器 包含年、月、日三个 CupertinoPicker 风格的滚轮

Inheritance

Constructors

ScrollDatePicker({Key? key, required DateTime initialDate, DateTime? minDate, DateTime? maxDate, ValueChanged<DateTime>? onDateChanged, double wheelHeight = 200, double itemExtent = 40, bool showYear = true, bool showConfirmButton = false, ValueChanged<DateTime>? onConfirm})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
initialDate DateTime
初始日期
final
itemExtent double
单项高度
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxDate DateTime?
最晚可选日期
final
minDate DateTime?
最早可选日期
final
onConfirm ValueChanged<DateTime>?
确认回调
final
onDateChanged ValueChanged<DateTime>?
日期变化回调
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showConfirmButton bool
是否显示确认按钮
final
showYear bool
是否显示年份
final
wheelHeight double
滚轮高度
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ScrollDatePicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited