WheelPicker class

CupertinoPicker 风格的单列滚轮选择器

Inheritance

Constructors

WheelPicker({Key? key, required int itemCount, int initialIndex = 0, double itemExtent = 40, required String labelBuilder(int index), ValueChanged<int>? onSelectedItemChanged, bool looping = false, TextStyle? selectedTextStyle, TextStyle? unselectedTextStyle})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
initialIndex int
初始选中项索引
final
itemCount int
选项数量
final
itemExtent double
每项的高度
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelBuilder String Function(int index)
构建每项的文字标签
final
looping bool
是否循环滚动
final
onSelectedItemChanged ValueChanged<int>?
选中项变化回调
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedTextStyle TextStyle?
选中项文字样式
final
unselectedTextStyle TextStyle?
未选中项文字样式
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<WheelPicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited