WeekView class

A full week view showing 7 day columns side by side with a shared time ruler on the left.

The content is vertically scrollable so all hours are accessible even on small screens.

Inheritance

Constructors

WeekView({Key? key, required DateTime weekStart, CalendarConfig config = const CalendarConfig(), List<CalendarEvent> events = const [], ValueChanged<DateTime>? onTimeTap, ValueChanged<CalendarEvent>? onEventTap})
const

Properties

config CalendarConfig
Calendar configuration (hours range, first day of week, etc.).
final
events List<CalendarEvent>
All events that may fall within this week.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onEventTap ValueChanged<CalendarEvent>?
Called when the user taps on an event.
final
onTimeTap ValueChanged<DateTime>?
Called when the user taps on an empty time slot.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weekStart DateTime
The start date of the week to display. If not aligned to the configured first day of week it will be adjusted automatically.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<WeekView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited