YearView class

年视图 - 以 3x4 或 4x3 网格展示 12 个月份缩略图

Inheritance

Constructors

YearView({Key? key, required int year, List<CalendarEvent> events = const [], ValueChanged<DateTime>? onMonthTap, ValueChanged<DateTime>? onDateTap, int firstDayOfWeek = 1, bool landscape = false})
const

Properties

events List<CalendarEvent>
事件列表(用于在月份缩略图上显示事件指示)
final
firstDayOfWeek int
周起始日(1=周一,7=周日)
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
landscape bool
是否使用横屏布局(4x3)
final
onDateTap ValueChanged<DateTime>?
点击某个日期时的回调
final
onMonthTap ValueChanged<DateTime>?
点击某个月份时的回调
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
year int
显示的年份
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited