DraggableEvent class

A long-press-draggable event card with shadow effect and haptic feedback.

Inheritance

Constructors

DraggableEvent({Key? key, required CalendarEvent event, ValueChanged<Offset>? onDragEnd, VoidCallback? onDragStart, VoidCallback? onTap, double? height})
const

Properties

event CalendarEvent
final
hashCode int
The hash code for this object.
no setterinherited
height double?
Height of the event card.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDragEnd ValueChanged<Offset>?
Called when the drag ends, providing the global position.
final
onDragStart VoidCallback?
Called when the drag starts.
final
onTap VoidCallback?
Called when the event is tapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DraggableEvent>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited