EventForm class

Form for creating or editing calendar events.

Inheritance

Constructors

EventForm({Key? key, CalendarEvent? event, required ValueChanged<CalendarEvent> onSave, VoidCallback? onCancel, DateTime? initialDate})
const

Properties

event CalendarEvent?
Pass an existing event to enter edit mode.
final
hashCode int
The hash code for this object.
no setterinherited
initialDate DateTime?
Initial date hint for new events.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCancel VoidCallback?
Called when the user cancels.
final
onSave ValueChanged<CalendarEvent>
Called when the user saves the form.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<EventForm>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited