ResizableEvent class
Event card with a bottom drag handle to resize its duration.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ResizableEvent
Constructors
-
ResizableEvent({Key? key, required CalendarEvent event, double minuteHeight = 1.0, ValueChanged<
Duration> ? onResizeEnd, ValueChanged<double> ? onResizeUpdate, VoidCallback? onTap, int minDurationMinutes = 15, int maxDurationMinutes = 480}) -
const
Properties
- event → CalendarEvent
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxDurationMinutes → int
-
Maximum duration in minutes.
final
- minDurationMinutes → int
-
Minimum duration in minutes.
final
- minuteHeight → double
-
Height per minute in the parent time view.
final
-
onResizeEnd
→ ValueChanged<
Duration> ? -
Called when resizing completes, providing the new duration.
final
-
onResizeUpdate
→ ValueChanged<
double> ? -
Called during resize, providing the current delta in pixels.
final
- onTap → VoidCallback?
-
Called when the event card is tapped.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ResizableEvent> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited