onResizeUpdate property
Called during resize, providing the current delta in pixels.
Implementation
final ValueChanged<double>? onResizeUpdate;
Called during resize, providing the current delta in pixels.
final ValueChanged<double>? onResizeUpdate;